import express from 'express';
const helmet = require('helmet');
const cors = require('cors');
const cookiep = require('cookie-parser');
const body = require("body-parser");
import HTTPError from './HTTPError'
import path from 'path';
import { randomBytes } from 'crypto';

export default class Router{

    #app: express.Application;
    #whitelist: string[];
    #admin_url: string = randomBytes(4).toString('hex');

    constructor(){
        
        this.#app = express();
        this.#whitelist = ['*'] // whitelist di domini per il CORS

        console.log(`admin url @ ${process.env.URI!}/${this.#admin_url}`);
        

    }

    init(): void{

        // facciamo un file separato per ogni gruppo di routes
        // così è tutto molto più organizzato

        let cors_options = {
            credentials: true,
            origin: this.#whitelist,
            allowedHeaders: ['Authorization'],
            methods: ['GET', 'POST', 'DELETE', 'PUT']
        }

        this.#app.use(helmet.contentSecurityPolicy({
  directives: {
    defaultSrc: ["'self'"],
    fontSrc: ["'self'", "fonts.gstatic.com", "kit-free.fontawesome.com"],
    scriptSrc: [
            "'self'",
            "'unsafe-eval'",
            "cdn.jsdelivr.net",
            "cdnjs.cloudflare.com",
            "kit-free.fontawesome.com",
            "kit.fontawesome.com",
            "unpkg.com",
            "*.quilljs.com",
            "cdnjs.cloudflare.com",
            "*.googleapis.com",
            "apis.google.com",
            (req, res) => `'nonce-${res.locals.nonce}'`
        ],
    styleSrc: [
      "'self'",
      "'unsafe-inline'",
      "fonts.googleapis.com",
      "kit.fontawesome.com",
      "kit-free.fontawesome.com",
      "*.quilljs.com",
      "fonts.gstatic.com"
    ],
  },
}));
        this.#app.use(cors(cors_options));
        this.#app.enable("trust proxy");
        this.#app.set("view engine", "twig");
        this.#app.set("views", path.resolve("app/views"))
        this.#app.disable("x-powered-by");
        this.#app.use(cookiep());
        this.#app.use(body.json({ limit: "20mb" }));
        this.#app.use(
            body.urlencoded({ limit: "20mb", extended: true, parameterLimit: 100 }),
        );

        this.#app.use('/assets', express.static(path.resolve("app/assets")));
        this.#app.use('/', require("./routes/main")); 
        // this.#app.use(`/${this.#admin_url}`, require("./routes/admin")) // prod
        this.#app.use('/admin', require("./routes/admin"));

        this.#app.all('*', (req: express.Request, res: express.Response) => {

            return HTTPError.NOT_FOUND.toResponse(res);
            
        })

        this.#app.listen(process.env.PORT);
        console.log(`listening on ${process.env.PORT}`);
        console.log(`live on ${process.env.URI}`);
    }

}